(function ($) {

  /**
   * The recommended way for producing HTML markup through JavaScript is to write
   * theming functions. These are similiar to the theming functions that you might
   * know from 'phptemplate' (the default PHP templating engine used by most
   * Drupal themes including Omega). JavaScript theme functions accept arguments
   * and can be overriden by sub-themes.
   *
   * In most cases, there is no good reason to NOT wrap your markup producing
   * JavaScript in a theme function.
   */
  Drupal.theme.prototype.ocioOmegaBaseExampleButton = function (path, title) {
    // Create an anchor element with jQuery.
    return $('<a href="' + path + '" title="' + title + '">' + title + '</a>');
  };

  /**
   * Behaviors are Drupal's way of applying JavaScript to a page. In short, the
   * advantage of Behaviors over a simple 'document.ready()' lies in how it
   * interacts with content loaded through Ajax. Opposed to the
   * 'document.ready()' event which is only fired once when the page is
   * initially loaded, behaviors get re-executed whenever something is added to
   * the page through Ajax.
   *
   * You can attach as many behaviors as you wish. In fact, instead of overloading
   * a single behavior with multiple, completely unrelated tasks you should create
   * a separate behavior for every separate task.
   *
   * In most cases, there is no good reason to NOT wrap your JavaScript code in a
   * behavior.
   *
   * @param context
   *   The context for which the behavior is being executed. This is either the
   *   full page or a piece of HTML that was just added through Ajax.
   * @param settings
   *   An array of settings (added through drupal_add_js()). Instead of accessing
   *   Drupal.settings directly you should use this because of potential
   *   modifications made by the Ajax callback that also produced 'context'.
   */
  Drupal.behaviors.ocioOmegaBaseExampleBehavior = {
    attach: function (context, settings) {

      // If browser has no svg support, replace svg images with pngs
      $('.no-svg img', context).each(function() {
        var src = $(this).attr('src').split('.');
        if (src.pop().toLowerCase() == 'svg') {
          src.push('png');
          $(this).attr('src', src.join('.'));
        }
      });

      if ($.fn.matchHeight) {
        /* Match tile panes to equal height */
        var rows = $('.node-type-ocio-landing-page .row-tiles .row-fluid');
        rows.each(function() {
          var resize = true;

          var row = $(this);
          var regions = row.find('.tile-panel');
          regions.each(function(row){

            if ($(this).find('.fieldable-panels-pane').size() > 1 ) {
              resize = false;
              return false;
            }
          });

          if (resize) {
            var panes = row.find('.tile-panel .fieldable-panels-pane');
            panes.find('.text-areas, .title-box').matchHeight({byRow: false});
            panes.matchHeight({byRow: false});
          }
        });
      }

      var toggleButton      = $('#search-block-toggle').eq(0);
      var searchBox         = $('#block-search-form').eq(0);
      var searchTextInput   = searchBox.find('input.form-text').eq(0);

      /**
       * The following reacts to clicks anywhere. If the click is within the
       * search box, the search box will stay visible. If the click is outside the
       * search box, the search box will be dismissed.
       */
      $(document).click(function(event) {
        toggleSearchBox(event);
      });

      /* Move Media Magnet channel icon to title area if only one channel is selected */
      $(document).ajaxSuccess(function( event, request, settings ) {
        if (settings.url.indexOf("mediamagnet.osu.edu/api") >= 0 ) {
          $('.pane-mm-widgets-live-pane.mm-channel-type-undefined').each(function() {
            panel = $(this);
            icons = panel.find('.item i.fa');
            panel.find('.fa-fw').attr('class',function(index, classes) {
              var newClass = icons.first().attr('class').match(/fa-[^\s]+/g);
              if (newClass) {
                panel.removeClass('mm-channel-type-undefined');
                classes = classes.replace('fa-fw', newClass);
                icons.remove();
                $(this).find('.element-invisible').text(newClass);
              }
              return classes;
            });
          });
        }
      });

      toggleButton.keypress(function(event){
        if (event.which === 13) {
          toggleSearchBox(event);
        }
      });

      function toggleSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        if (clickTarget.attr('id') == toggleButton.attr('id')) {
          // Clicked the toggle button.
          if (searchBox.is(':visible') ){
            // Turn sticky visibility on.
            hideHoverSearchBox();
          }
          else {
            showHoverSearchBox();
          }
        }
        else if (clickedSearchBox(event)) {
          return;
        }
        else if (searchBox.is(':visible')) {
          // This only matters if the search box is currently visible.
          hideHoverSearchBox(true);
        }
      }

      /*
       * Determines if the target clicked was inside the search box.
       */
      function clickedSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        var inSearchBox = false;
        // Check if the search box itself was clicked.
        if (searchBox.get(0) == clickTarget.get(0)) {
          // Search box was clicked.
          inSearchBox = true;
        }
        else {
          /*
           * Compare the click target against all the elements in the search box
           * to determine if the clicked element is part of it.
           */
          var elements = searchBox.find('*');
          elements.each(function(index) {
            if (elements.eq(index).get(0) == clickTarget.get(0)) {
              // Search box element was clicked.
              inSearchBox = true;
              return;
            }
          });
        }
        return inSearchBox;
      }

      /*
       * Displays the hover search box.
       */
      function showHoverSearchBox() {
        searchBox.stop(true, true).clearQueue().fadeIn('fast');
        toggleButton.addClass('fa-search-minus');
      }

      /*
       * Hides the hover search box when applicable.
       *
       * @param force
       *   If set to TRUE, forces the search box to be hidden and disables
       *   the sticky visibility parameter.
       */
      function hideHoverSearchBox(force) {

        if (force != undefined) {
          if (force === true) {
            // Hide the box and turn sticky visibility off.
            hideHoverSearchBox_do();
            return;
          }
        }

        if (!searchBox.is(':focus')) {
          hideHoverSearchBox_do();
        }
      }

      function hideHoverSearchBox_do() {
        // Handles the actual hiding, without any logical operations.
        searchBox.stop(true, true).fadeOut('fast')
        toggleButton.removeClass('fa-search-minus');
      }
    }
  };


 /*** Adds/alters classes for mean-menu ***/

  Drupal.behaviors.ocioOmegaBaseMeanMenu = {
		attach: function (context, settings) {

  		$(".mean-container .mean-nav ul li span").addClass("nolink");
		}
  };


})(jQuery);
